#![feature(downcast_unchecked)]
#![feature(async_closure)]

use config::ConfigWrapper;

mod manifest;
mod logger;
mod downloader;
mod util;
mod config;
mod constants;
mod process_manager;
mod ui;
mod prompt;
mod data;



#[tokio::main]
async fn main() {
    let Ok(cfg) = ConfigWrapper::parse() else {
        return;
    };
    
    let mut manifest = match manifest::Manifest::load_new(&cfg.cli.manifest.clone().into_std_path_buf()) {
        Ok(m) => m,
        Err(e) => {
            log::error!("Failed to parse manifest file {}: {e}", cfg.cli.manifest);
            return;
        }
    };

    
    let _ = ui::cli::command_run(&cfg, &mut manifest);
}
