mod add;

use crate::{config::{cli::CliCommand, ConfigWrapper}, downloader::Downloader, manifest::Manifest, ui::gui};



pub fn command_run(cfg: &ConfigWrapper, manifest: &mut Manifest) -> anyhow::Result<()> {
    log::info!("Is in term: {}", cfg.isatty);
    //std::fs::write("./isatty", format!("{}\n", cfg.isatty))?;

    let mut downloader = Downloader::new();
    match (&cfg.cli.command, cfg.isatty) {
        (None | Some(CliCommand::Download), true) => {
            match downloader.download_all(manifest, cfg) {
                Ok(count) => log::info!("Downloaded {count} songs"),
                Err(e) => {
                    log::error!("Failed to download songs: {e}");
                    return Ok(());
                }
            }
        },
        (Some(c), _) => {
            match c {
                CliCommand::Download => unreachable!(),
                CliCommand::AddPlaylist { url, name } => {
                    if let Err(e) = add::playlist(cfg, manifest, &mut downloader, url, name) {
                        log::error!("Failed to run 'add-playlist' commmand: {e}");
                    }
                }
                CliCommand::Add { url, name, playlist  } => {
                    if let Err(e) = add::song(cfg, manifest, &mut downloader, url, name, playlist) {
                        log::error!("Failed to run 'add' command: {e}");
                    }
                }
                CliCommand::Gui => {
                    gui::Gui::start(manifest.clone(), downloader, cfg.clone())?;
                },
            }
        }
        (None, false) => {
            gui::Gui::start(manifest.clone(), downloader, cfg.clone())?;
        },
    }

    Ok(())
}
