use crate::ui::gui::{windows::WindowIndex, Gui};

use super::Component;

pub struct NavBar;

impl Component for NavBar {
    fn ui(gui: &mut Gui, ctx: &egui::Context) {
        egui::TopBottomPanel::top("top_panel").show(ctx, |ui| {
            // The top panel is often a good place for a menu bar:
            egui::menu::bar(ui, |ui| {
                ui.menu_button("File", |ui| {
                    if ui.button("Source").clicked() {
                        ctx.open_url(egui::OpenUrl::new_tab("https://git.mcorangehq.xyz/XOR64/music"));
                    }
                    if ui.button("Save").clicked() {
                        if let Err(e) =  gui.manifest.save(None) {
                            log::error!("Failed to save manifest: {e}");
                        }
                    }
                    if ui.button("Quit").clicked() {
                        ctx.send_viewport_cmd(egui::ViewportCommand::Close);
                    }
                });

                ui.menu_button("Song", |ui| {
                    if ui.button("Add New").clicked() {
                        gui.windows.open(WindowIndex::SongNew, true);
                    }
                });

                ui.menu_button("Playlist", |ui| {
                    if ui.button("Import").clicked() {
                        gui.windows.open(WindowIndex::ImportPlaylist, true);
                    }
                });

                ui.menu_button("Downloader", |ui| {
                    if ui.button("Download All").clicked() {
                        if let Err(e) = gui.downloader.download_all_nb(&gui.manifest, &gui.cfg) {
                            log::error!("Err: {e}");
                        }
                    }
                });
                ui.add_space(16.0);
                ui.with_layout(egui::Layout::bottom_up(egui::Align::RIGHT), |ui| {
                    ui.horizontal(|ui| {
                        if gui.downloader.get_songs_left_nb() > 0 {
                            gui.downloading = true;
                            ui.label(format!("Downloading: {}/{}", gui.downloader.get_songs_left_nb(), gui.downloader.get_initial_song_count_nb()));
                        } else if gui.downloading {
                            let _ = notify_rust::Notification::new()
                                .summary("Done downloading")
                                .body("Your music has been downloaded")
                                .show();
                            gui.downloading = false;
                        }
                        let _ = gui.downloader.download_all_nb_poll(&gui.cfg);
                        egui::widgets::global_dark_light_mode_buttons(ui);
                    });
                });
            });
        });

    } 
}
