use egui::{Color32, RichText};

use crate::ui::gui::{components::ComponentContextMenu, windows::{self, WindowIndex}};


#[derive(Debug)]
pub struct ContextMenu;

impl ComponentContextMenu for ContextMenu {
    type Data = String; // Playlist name
    fn ui(gui: &mut crate::ui::gui::Gui, ui: &mut egui::Ui, playlist_name: &Self::Data) {
        if ui.button("Edit").clicked() {
            ui.close_menu();
        }

        if ui.button("Download all").clicked() {
            let Some(playlist) = gui.manifest.get_playlist(playlist_name) else {
                gui.throw_error(format!("Playlist not found: {}", playlist_name));
                ui.close_menu();
                return;
            };

            for (song_name, song) in playlist.get_songs() {
                if let Err(e) = gui.downloader.download_song_nb(&gui.cfg, playlist_name, song_name, song, gui.manifest.get_format()) {
                    gui.throw_error(format!("Could not download song: {e}"));
                    ui.close_menu();
                    return;
                }
            }
            ui.close_menu();
        }

        if ui.button("Delete from disk").clicked() {
            let p = crate::util::get_playlist_path(playlist_name);
            if p.exists() {
                if let Err(e) = std::fs::remove_dir_all(p) {
                    gui.throw_error(format!("Failed to delete directory: {e}"));
                }
            }
            ui.close_menu();
        }
        if ui.button(RichText::new("Delete").color(Color32::RED)).clicked() {
            let w = gui.windows.get_window::<windows::confirm::ConfirmW>(WindowIndex::Confirm);
            w.set_message(
                "side_nav_playlist_manifest_delete", 
                "This will delete the playlist from the manifest file. This is NOT reversible", 
                &[playlist_name.clone()]
            );
            gui.windows.open(WindowIndex::Confirm, true);
            ui.close_menu();
        }

        
    }
}
