use egui::{Color32, Label, RichText, Sense};
use crate::ui::gui::windows::{self, WindowIndex};

use super::{ComponentContextMenu, ComponentUi};

mod context_menu;



pub struct SideNav;

impl ComponentUi for SideNav {
    fn ui(gui: &mut crate::ui::gui::Gui, ui: &mut egui::Ui) {
        let mut playlist_names = gui.manifest
            .get_playlists()
            .keys().cloned().collect::<Vec<String>>();

        playlist_names.sort_by_key(|name| name.to_lowercase());
        ui.with_layout(egui::Layout::top_down(egui::Align::TOP), |ui| {
            
            for pname in playlist_names {
                if gui.current_playlist.is_empty() {
                    gui.current_playlist = pname.to_string();
                }
                ui.horizontal(|ui| {
                    let tint = Color32::from_hex("#333377").unwrap();
                    ui.add(egui::Image::new(crate::data::NOTE_ICON).tint(tint))
                        .context_menu(|ui| context_menu::ContextMenu::ui(gui, ui, &pname));

                    ui.horizontal(|ui| {
                        let text = if gui.current_playlist == *pname {
                            RichText::new(&pname).color(tint)
                        } else {
                            RichText::new(&pname)
                        };
                        
                        let button = Label::new(text).sense(Sense::click()).selectable(false);
                        let button = ui.add(button);
                        if button.clicked() {
                            gui.current_playlist = pname.to_string();
                        }

                        button.context_menu(|ui| context_menu::ContextMenu::ui(gui, ui, &pname));
                    });
                });

            } 
        });
        
        check_if_needs_delete(gui);
    }
    // #333377
}


fn check_if_needs_delete(gui: &mut crate::ui::gui::Gui) {
    // Check for items that need to be deleted
    let (id, resp, data) = gui.windows.get_window::<windows::confirm::ConfirmW>(WindowIndex::Confirm).get_response();
    match (id.as_str(), resp) {
        ("side_nav_playlist_manifest_delete", Some(true)) => {
            gui.manifest.remove_playlist(&data[0]);
            let _ = gui.manifest.save(None);
            gui.windows.get_window::<windows::confirm::ConfirmW>(WindowIndex::Confirm).reset();
        }
        ("side_nav_playlist_manifest_delete", Some(false)) => {
            log::debug!("FALSE");
            gui.windows.get_window::<windows::confirm::ConfirmW>(WindowIndex::Confirm).reset();
        }
        _ => ()
    }

}
