use crate::manifest::song::SongType;

use super::{State, Window};


#[allow(clippy::pedantic)]
#[derive(Debug, Default)]
pub struct GuiImportPlaylist {
    ed_type: SongType,
    ed_name: String,
    ed_url: String,
    //urls_to_add: Vec<String>,
    // playlist_name: String,
}


impl Window for GuiImportPlaylist {
    fn ui(&mut self, state: &mut State, ctx: &egui::Context, open: &mut bool) -> anyhow::Result<()> {
        let mut save = false;
        egui::Window::new("Import Playlist")
            .open(open)
            .show(ctx, |ui| {
                ui.horizontal(|ui| {
                    ui.label("Type: ");
                    egui::ComboBox::from_id_source("new_playlist_window_type")
                        .selected_text(format!("{:?}", self.ed_type))
                        .show_ui(ui, |ui| {
                            ui.selectable_value(&mut self.ed_type, SongType::Youtube, "Youtube");
                            ui.selectable_value(&mut self.ed_type, SongType::Spotify, "Spotify");
                            // ui.selectable_value(&mut self.ed_type, SongType::Soundcloud, "Soundcloud");
                        }
                    );   
                });

                ui.horizontal(|ui| {
                    ui.label("Name: ");
                    ui.text_edit_singleline(&mut self.ed_name);
                });
                ui.horizontal(|ui| {
                    ui.label("Url: ");
                    ui.text_edit_singleline(&mut self.ed_url);
                });

                if ui.button("Import").clicked() {
                    save = true;
                }
        });

        //if let Some(_) = self.urls_to_add.pop() {
          //  todo!();
            //let client = reqwest::blocking::Client::new();
            // let song_name = crate::crawler::spotify::get_song_name(&client, url.clone())?;

            //if let Some(playlist) = state.manifest.get_playlist_mut(&self.playlist_name) {
            //    let mut song = Song::from_url_str(url)?;
            //    song.set_type(SongType::Spotify);
            //    playlist.add_song(song_name, song);
            //}
            //let _ = state.manifest.save(None);
        //}


        if save {
            let name = self.ed_name.clone();
            let url = self.ed_url.clone();

            if state.manifest.get_playlist(&name).is_some() {
                log::error!("Playlist {name} already exists");
            }
            if self.ed_type == SongType::Spotify {
                todo!()
                //let client = reqwest::blocking::Client::new();
                //self.urls_to_add = crate::crawler::spotify::get_playlist_song_urls(&client, self.ed_url.clone())?;
                //self.playlist_name = self.ed_name.clone();
                //state.manifest.add_playlist(name.clone());
            } else if self.ed_type == SongType::Youtube {
                let songs = state.downloader.download_playlist_nb(&state.cfg, &url, &name, state.manifest.get_format()).unwrap();
                state.manifest.add_playlist(name.clone());

                let playlist = state.manifest.get_playlist_mut(&name).expect("Unreachable");
                
                for (sname, song) in songs {
                    log::info!("Added: {sname}");
                    playlist.add_song(sname, song);
                }
            }
            let _ = state.manifest.save(None);
            *open = false;
        }

        Ok(())
    }
}
